==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ALookupswitchStatement__24CaseStmt__5fCast.h <==
// class soot.jimple.parser.node.ALookupswitchStatement$CaseStmt_Cast

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 654afaf8a654ad0 soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast_H_
#define _JC_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_jimple_parser_node_ALookupswitchStatement$object;
struct _jc_soot_jimple_parser_node_ALookupswitchStatement__241$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$sub_refs	_jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$sub_nonrefs	_jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$refs	_jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$refs;
typedef struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$nonrefs	_jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$object	_jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$object;

typedef const struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$vmethods	_jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$vtable	_jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$vtable;
typedef const struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$vtype	_jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$method$_init$6b2aaab54761ed84(_jc_env *, struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$object *, struct _jc_soot_jimple_parser_node_ALookupswitchStatement$object *);
extern void _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$method$_init$2834e36ef7ecd335(_jc_env *, struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$object *, struct _jc_soot_jimple_parser_node_ALookupswitchStatement$object *, struct _jc_soot_jimple_parser_node_ALookupswitchStatement__241$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$method$cast$7f4f4803dccc49ec(_jc_env *, struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$method_info$cast$7f4f4803dccc49ec;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$vmethods {
	struct _jc_java_lang_Object$object	*(*cast$7f4f4803dccc49ec)(_jc_env *, struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$vmethods	soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast;
};

// Vtype
struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$sub_refs {
	struct _jc_soot_jimple_parser_node_ALookupswitchStatement$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$refs {
    _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$sub_refs	soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$sub_nonrefs	soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$object {
	_jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$vtype	*vtype;
	_jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$vtype _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$class_object;

#endif	/* _JC_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ALookupswitchStatement__24CaseStmt__5fCast.h <==
// class soot.jimple.parser.node.ALookupswitchStatement$CaseStmt_Cast

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 654afaf8a654ad0 soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast_H_
#define _JC_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_jimple_parser_node_ALookupswitchStatement$object;
struct _jc_soot_jimple_parser_node_ALookupswitchStatement__241$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$sub_refs	_jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$sub_nonrefs	_jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$refs	_jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$refs;
typedef struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$nonrefs	_jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$object	_jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$object;

typedef const struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$vmethods	_jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$vtable	_jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$vtable;
typedef const struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$vtype	_jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$method$_init$6b2aaab54761ed84(_jc_env *, struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$object *, struct _jc_soot_jimple_parser_node_ALookupswitchStatement$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$method$_init$2834e36ef7ecd335(_jc_env *, struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$object *, struct _jc_soot_jimple_parser_node_ALookupswitchStatement$object *, struct _jc_soot_jimple_parser_node_ALookupswitchStatement__241$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$method$cast$7f4f4803dccc49ec(_jc_env *, struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$method_info$cast$7f4f4803dccc49ec;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$vmethods {
	struct _jc_java_lang_Object$object	*(*cast$7f4f4803dccc49ec)(_jc_env *, struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$vmethods	soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast;
};

// Vtype
struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$sub_refs {
	struct _jc_soot_jimple_parser_node_ALookupswitchStatement$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$refs {
    _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$sub_refs	soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$sub_nonrefs	soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$object {
	_jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$vtype	*vtype;
	_jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$vtype _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast$class_object;

#endif	/* _JC_soot_jimple_parser_node_ALookupswitchStatement__24CaseStmt__5fCast_H_ */
